@@ -13,8 +13,9 @@ package Image::ExifTool::IPTC;
 
 use strict;
 use vars qw($VERSION $AUTOLOAD %iptcCharset);
+use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.44';
+$VERSION = '1.47';
 
 %iptcCharset = (
     "\x1b%G"  => 'UTF8',
@@ -32,6 +33,17 @@ sub CheckIPTC($$$);
 sub PrintCodedCharset($);
 sub PrintInvCodedCharset($);
 
+# standard IPTC locations
+# (MWG specifies locations only for JPEG, TIFF and PSD -- the rest are ExifTool-defined)
+my %isStandardIPTC = (
+    'JPEG-APP13-Photoshop-IPTC' => 1,
+    'TIFF-IFD0-IPTC'            => 1,
+    'PSD-IPTC'                  => 1,
+    'MIE-IPTC'                  => 1,
+    'EPS-Photoshop-IPTC'        => 1,
+    'PS-Photoshop-IPTC'         => 1,
+);
+
 my %fileFormat = (
     0 => 'No ObjectData',
     1 => 'IPTC-NAA Digital Newsphoto Parameter Record',
@@ -358,7 +370,7 @@ my %fileFormat = (
             '' => '',
             '01' => 'Object Kill',
             '02' => 'Object Replace',
-            '03' => 'Ojbect Append',
+            '03' => 'Object Append',
             '04' => 'Object Reference',
         },
     },
@@ -1007,7 +1019,7 @@ sub TranslateCodedString($$$$)
 sub IsStandardIPTC($)
 {
     my $path = shift;
-    return $path =~ /^(JPEG-APP13-Photoshop-IPTC|TIFF-IFD0-IPTC|PSD-IPTC|MIE-IPTC)$/
+    return $isStandardIPTC{$path};
 }
 
 #------------------------------------------------------------------------------
@@ -1069,6 +1081,16 @@ sub ProcessIPTC($$$)
         $dirEnd = $pos + $dirLen;
         # NOTE: MUST NOT access $dirInfo DataPt, DirStart or DataLen after this!
     }
+    # extract IPTC as a block if specified
+    if ($exifTool->{REQ_TAG_LOOKUP}{iptc} or ($exifTool->{OPTIONS}{Binary} and
+        not $exifTool->{EXCL_TAG_LOOKUP}{iptc}))
+    {
+        if ($pos or $dirLen != length($$dataPt)) {
+            $exifTool->FoundTag('IPTC', substr($$dataPt, $pos, $dirLen));
+        } else {
+            $exifTool->FoundTag('IPTC', $$dataPt);
+        }
+    }
     while ($pos + 5 <= $dirEnd) {
         my $buff = substr($$dataPt, $pos, 5);
         my ($id, $rec, $tag, $len) = unpack("CCCn", $buff);
@@ -1124,7 +1146,7 @@ sub ProcessIPTC($$$)
         unless ($$recordPtr{$tag}) {
             # - no Format so format is auto-detected
             # - no Name so name is generated automatically with decimal tag number
-            Image::ExifTool::AddTagToTable($recordPtr, $tag, { Unknown => 1 });
+            AddTagToTable($recordPtr, $tag, { Unknown => 1 });
         }
 
         my $tagInfo = $exifTool->GetTagInfo($recordPtr, $tag);
