@@ -29,7 +29,7 @@ use vars qw($VERSION %leicaLensTypes);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.63';
+$VERSION = '1.68';
 
 sub ProcessPanasonicType2($$$);
 sub WhiteBalanceConv($;$$);
@@ -42,9 +42,10 @@ sub WhiteBalanceConv($;$$);
         return $$conv{$val};
     },
     Notes => q{
-        Entries with 2 numbers give the lower 2 bits of the LensType value which are
-        used to identify certain manually coded lenses on the M9, or the focal
-        length of some multi-focal lenses.
+        the LensType value is obtained by splitting the stored value into 2
+        integers:  The stored value divided by 4, and its lower 2 bits.  The second
+        number is used only if necessary to identify certain manually coded lenses
+        on the M9, or the focal length of some multi-focal lenses.
     },
     # All M9 codes (two numbers: first the LensID then the lower 2 bits)
     # are ref PH with samples from ref 13.  From ref 10, the lower 2 bits of
@@ -113,8 +114,8 @@ sub WhiteBalanceConv($;$$);
     51 => 'Super-Elmar-M 21mm f/3.4 Asph',  # ? (ref 16, frameSelectorBits=1)
     '51 2' => 'Super-Elmar-M 14mm f/3.8 Asph', # ? (ref 16)
     52 => 'Super-Elmar-M 18mm f/3.8 ASPH.', # ? (ref PH/11)
-    53 => 'Apo-Telyt-M 135mm f/3.4',        # ? (ref 16)
-
+    '53 2' => 'Apo-Telyt-M 135mm f/3.4', #16
+    '53 3' => 'Apo-Summicron-M 50mm f/2 Asph', #16
 );
 
 # M9 frame selector bits for each lens
@@ -208,7 +209,12 @@ my %shootingMode = (
     44 => 'Film Grain', #PH (FZ28)
     45 => 'My Color', #PH (GF1)
     46 => 'Photo Frame', #PH (FS7)
+    # 49 - seen for FS4 (snow?)
     51 => 'HDR', #12
+    55 => 'Handheld Night Shot', #PH (FZ47)
+    57 => '3D', #PH (3D1)
+    59 => 'Creative Control', #PH (FZ47)
+    66 => 'Digital Filter', #PH (GF5 "Impressive Art", "Cross Process", "Color Select", "Star")
 );
 
 %Image::ExifTool::Panasonic::Main = (
@@ -290,6 +296,7 @@ my %shootingMode = (
             PrintConv => { #PH
                 '0 1'   => '9-area', # (FS7)
                 '0 16'  => '3-area (high speed)', # (FZ8)
+                '0 23'  => '23-area', #PH (FZ47,NC)
                 '1 0'   => 'Spot Focusing', # (FZ8)
                 '1 1'   => '5-area', # (FZ8)
                 '16'    => 'Normal?', # (only mode for DMC-LC20)
@@ -332,7 +339,11 @@ my %shootingMode = (
     0x20 => {
         Name => 'Audio',
         Writable => 'int16u',
-        PrintConv => { 1 => 'Yes', 2 => 'No' },
+        PrintConv => {
+            1 => 'Yes',
+            2 => 'No',
+            3 => 'Stereo', #PH (NC)
+        },
     },
     0x21 => { #2
         Name => 'DataDump',
@@ -441,7 +452,7 @@ my %shootingMode = (
     0x2c => [
         {
             Name => 'ContrastMode',
-            Condition => '$$self{Model} !~ /^DMC-(FX10|G1|L1|L10|LC80|GF1|TZ10|ZS7)$/',
+            Condition => '$$self{Model} !~ /^DMC-(FX10|G1|L1|L10|LC80|GF\d+|G2|TZ10|ZS7)$/',
             Flags => 'PrintHex',
             Writable => 'int16u',
             Notes => q{
@@ -457,6 +468,7 @@ my %shootingMode = (
                 # 5 - observed with FX01, FX40 and FP8 (EXIF contrast "Normal") - PH
                 6 => 'Medium Low', #PH (FZ18)
                 7 => 'Medium High', #PH (FZ18)
+                13 => 'High Dynamic', #PH (FZ47 in ?)
                 # DMC-LC1 values:
                 0x100 => 'Low',
                 0x110 => 'Normal',
@@ -464,26 +476,36 @@ my %shootingMode = (
             }
         },{
             Name => 'ContrastMode',
-            Condition => '$$self{Model} eq "DMC-GF1"',
-            Notes => 'these values are used by the GF1',
+            Condition => '$$self{Model} =~ /^DMC-(GF\d+|G2)$/',
+            Notes => 'these values are used by the G2, GF1, GF2, GF3 and GF5',
             Writable => 'int16u',
-            PrintConv => {
+            PrintConv => { # (decoded for GF1 unless otherwise noted)
                 0 => '-2',
                 1 => '-1',
                 2 => 'Normal',
                 3 => '+1',
                 4 => '+2',
                 # Note: Other Contrast tags will be "Normal" in any of these modes:
-                7 => 'Nature (Color Film)',
-                12 => 'Smooth (Color Film) or Pure (My Color)',
-                17 => 'Dynamic (B&W Film)',
-                22 => 'Smooth (B&W Film)',
-                27 => 'Dynamic (Color Film)',
-                32 => 'Vibrant (Color Film) or Expressive (My Color)',
+                # 5 - seen for Portrait (FX80)
+                7 => 'Nature (Color Film)', # (GF1,G2; GF3 "Miniature")
+                9 => 'Expressive', #(GF3)
+                12 => 'Smooth (Color Film) or Pure (My Color)', #(GF1,G2 "Smooth Color")
+                17 => 'Dynamic (B&W Film)', #(GF1,G2)
+                22 => 'Smooth (B&W Film)', #(GF1,G2)
+                25 => 'High Dynamic', #(GF5)
+                26 => 'Retro', #(GF5)
+                27 => 'Dynamic (Color Film)', #(GF1,G2) (GF3 "High Key")
+                28 => 'Low Key', #(GF5)
+                29 => 'Toy Effect', #(GF5)
+                32 => 'Vibrant (Color Film) or Expressive (My Color)', # (GF1; G2 "Vibrant"; GF2,GF5 "Expressive")
                 33 => 'Elegant (My Color)',
-                37 => 'Nostalgic (Color Film)',
-                41 => 'Dynamic Art (My Color)',
+                37 => 'Nostalgic (Color Film)', # (GF1,G2; GF5 "Sepia")
+                41 => 'Dynamic Art (My Color)', # (GF5 "High Key")
                 42 => 'Retro (My Color)',
+                45 => 'Cinema', #(GF2)
+                47 => 'Dynamic Mono', #(GF5)
+                50 => 'Impressive Art', #(GF5)
+                51 => 'Cross Process', #(GF5)
             },
         },{
             Name => 'ContrastMode',
@@ -612,37 +634,15 @@ my %shootingMode = (
         Name => 'ProgramISO', # (maybe should rename this ISOSetting?)
         Writable => 'int16u',
         PrintConv => {
-            OTHER => sub { return shift },
+            OTHER => sub { shift },
             65534 => 'Intelligent ISO', #PH (FS7)
             65535 => 'n/a',
         },
     },
     0x3d => { #PH
-        Name => 'AdvancedSceneMode',
+        Name => 'AdvancedSceneType',
         Writable => 'int16u',
-        # values for the FZ28 (SceneMode/AdvancedSceneMode, "*"=add mode name) - PH:
-        # Portrait: 2/1=Normal*, 24/1=Soft Skin, 2/2=Outdoor*, 2/3=Indoor*, 2/4=Creative*
-        # Scenery: 3/1=Normal*, 3/2=Nature, 3/3=Architecture, 3/4=Creative*
-        # Sports: 4/1=Normal*, 4/2=Outdoor*, 4/3=Indoor*, 4/4=Creative*
-        # Night Scenery: 5/1=Night Portrait, 21/1=*, 21/2=Illuminations, 21/4=Creative*
-        # Macro (Close-up): 9/2=Flower, 22/1=Food, 9/3=Objects, 9/4=Creative*
-        # - have seen value of 5 for TZ5 (Macro) and FS20 (Scenery and Intelligent Auto)
-        #   --> I'm guessing this is "Auto" - PH
-        # - values for HDR mode (ref 12): 1=Standard, 2=Art, 3=B&W
-        PrintConv => {
-            1 => 'Normal',
-            2 => 'Outdoor/Illuminations/Flower/HDR Art',
-            3 => 'Indoor/Architecture/Objects/HDR B&W',
-            4 => 'Creative',
-            5 => 'Auto',
-            7 => 'Expressive', #(GF1)
-            8 => 'Retro', #(GF1)
-            9 => 'Pure', #(GF1)
-            10 => 'Elegant', #(GF1)
-            12 => 'Monochrome', #(GF1)
-            13 => 'Dynamic Art', #(GF1)
-            14 => 'Silhouette', #(GF1)
-        },
+        Notes => 'used together with SceneMode to derive Composite AdvancedSceneMode',
     },
     0x3e => { #PH (TZ5/FS7)
         # (tags 0x3b, 0x3e, 0x8008 and 0x8009 have the same values in all my samples - PH)
@@ -680,8 +680,8 @@ my %shootingMode = (
             7 => 'Smooth (B&W)',
             # 8 => 'My Film 1'? (from owner manual)
             # 9 => 'My Film 2'?
-            10 => 'Nostalgic', # GH1
-            11 => 'Vibrant', # GH1
+            10 => 'Nostalgic', #(GH1)
+            11 => 'Vibrant', #(GH1)
             # 12 => 'Multi Film'? (in the GH1 specs)
         },
     },
@@ -692,13 +692,13 @@ my %shootingMode = (
     },
     # 0x45 - int16u: 0
     0x46 => { #PH/JD
-        Name => 'WBAdjustAB',
+        Name => 'WBShiftAB',
         Format => 'int16s',
         Writable => 'int16u',
         Notes => 'positive is a shift toward blue',
     },
     0x47 => { #PH/JD
-        Name => 'WBAdjustGM',
+        Name => 'WBShiftGM',
         Format => 'int16s',
         Writable => 'int16u',
         Notes => 'positive is a shift toward green',
@@ -869,6 +869,15 @@ my %shootingMode = (
         },
     },
     # 0x7a,0x7b: 0
+    0x86 => { #http://dev.exiv2.org/issues/825
+        Name => 'ManometerPressure',
+        Writable => 'int16u',
+        RawConv => '$val==65535 ? undef : $val',
+        ValueConv => '$val / 10',
+        ValueConvInv => '$val * 10',
+        PrintConv => 'sprintf("%.1f kPa",$val)',
+        PrintConvInv => '$val=~s/ ?kPa//i; $val',
+    },
     0x0e00 => {
         Name => 'PrintIM',
         Description => 'Print Image Matching',
@@ -1312,11 +1321,31 @@ my %shootingMode = (
             '3 0 0 0' => 'Manual',
         },
     },
-    # 0x0411 - saturation or sharpness
+    0x0410 => {
+        Name => 'ShotInfo',
+        SubDirectory => { TagTable => 'Image::ExifTool::Panasonic::ShotInfo' },
+    },
+    # 0x0410 - int8u[16]: first byte is FileNumber 
+    # 0x0411 - int8u[4]: first number is FilmMode (1=Standard,2=Vivid,3=Natural,4=BW Natural,5=BW High Contrast)
     0x0412 => { Name => 'FilmMode',         Writable => 'string' },
     0x0413 => { Name => 'WB_RGBLevels',     Writable => 'rational64u', Count => 3 },
 );
 
+# Leica type5 ShotInfo (ref PH) (X2)
+%Image::ExifTool::Panasonic::ShotInfo = (
+    PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
+    WRITE_PROC => \&Image::ExifTool::WriteBinaryData,
+    CHECK_PROC => \&Image::ExifTool::CheckBinaryData,
+    GROUPS => { 0 => 'MakerNotes', 1 => 'Leica', 2 => 'Camera' },
+    TAG_PREFIX => 'Leica_ShotInfo',
+    FIRST_ENTRY => 0,
+    WRITABLE => 1,
+    0 => {
+        Name => 'FileIndex',
+        Format => 'int16u',
+    },
+);
+
 # Leica type6 maker notes (ref PH) (S2)
 %Image::ExifTool::Panasonic::Leica6 = (
     WRITE_PROC => \&Image::ExifTool::Exif::WriteExif,
@@ -1520,7 +1549,7 @@ my %shootingMode = (
     },
     0x4068 => {
         Name => 'ExifData',
-        Condition => '$$valPt =~ /^\xff\xd8\xff\xe1..Exif\0\0/',
+        Condition => '$$valPt =~ /^\xff\xd8\xff\xe1..Exif\0\0/s',
         SubDirectory => {
             TagTable => 'Image::ExifTool::Exif::Main',
             ProcessProc => \&Image::ExifTool::ProcessTIFF,
@@ -1529,6 +1558,74 @@ my %shootingMode = (
     },
 );
 
+# Panasonic Composite tags
+%Image::ExifTool::Panasonic::Composite = (
+    GROUPS => { 2 => 'Camera' },
+    AdvancedSceneMode => {
+        SeparateTable => 'Panasonic AdvancedSceneMode',    # print values in a separate table
+        Require => {
+            0 => 'SceneMode',
+            1 => 'AdvancedSceneType',
+        },
+        ValueConv => '"$val[0] $val[1]"',
+        PrintConv => { #PH
+            OTHER => sub {
+                my $val = shift;
+                my @v = split ' ', $val;
+                my $prt = $shootingMode{$v[0]};
+                return $v[1] == 1 ? $prt : "$prt ($v[1])" if $prt;
+                return "Unknown ($val)";
+            },
+            Notes => 'A Composite tag derived from SceneMode and AdvancedSceneType.',
+            '0 1' => 'Off',
+            '2 2' => 'Outdoor Portrait', #(FZ28)
+            '2 3' => 'Indoor Portrait', #(FZ28)
+            '2 4' => 'Creative Portrait', #(FZ28)
+            '3 2' => 'Nature', #(FZ28)
+            '3 3' => 'Architecture', #(FZ28)
+            '3 4' => 'Creative Scenery', #(FZ28)
+            #'3 5' - ? (FT1)
+            '4 2' => 'Outdoor Sports', #(FZ28)
+            '4 3' => 'Indoor Sports', #(FZ28)
+            '4 4' => 'Creative Sports', #(FZ28)
+            '9 2' => 'Flower', #(FZ28)
+            '9 3' => 'Objects', #(FZ28)
+            '9 4' => 'Creative Macro', #(FZ28)
+            #'9 5' - ? (GF3)
+            '21 2' => 'Illuminations', #(FZ28)
+            '21 4' => 'Creative Night Scenery', #(FZ28)
+            #'21 5' - ? (LX3)
+            #'37 5' - ? (various)
+            '45 2' => 'Cinema', #(GF2)
+            '45 7' => 'Expressive', #(GF1,GF2)
+            '45 8' => 'Retro', #(GF1,GF2)
+            '45 9' => 'Pure', #(GF1,GF2)
+            '45 10' => 'Elegant', #(GF1,GF2)
+            '45 12' => 'Monochrome', #(GF1,GF2)
+            '45 13' => 'Dynamic Art', #(GF1,GF2)
+            '45 14' => 'Silhouette', #(GF1,GF2)
+            '51 2' => 'HDR Art', #12
+            '51 3' => 'HDR B&W', #12
+            '59 1' => 'Expressive', #(GF5)
+            '59 2' => 'Retro', #(GF5)
+            '59 3' => 'High Key', #(GF5)
+            '59 4' => 'Sepia', #(GF3,GF5)
+            '59 5' => 'High Dynamic', #(GF3,GF5)
+            '59 6' => 'Minature', #(GF3)
+            '59 9' => 'Low Key', #(GF5)
+            '59 10' => 'Toy Effect', #(GF5)
+            '59 11' => 'Dynamic Monochrome', #(GF5)
+            '59 12' => 'Soft', #(GF5)
+            '66 2' => 'Cross Process', #(GF5)
+            '66 3' => 'Color Select', #(GF5)
+            '66 4' => 'Star', #(GF5)
+        },
+    },
+);
+
+# add our composite tags
+Image::ExifTool::AddCompositeTags('Image::ExifTool::Panasonic');
+
 #------------------------------------------------------------------------------
 # Inverse conversion for Leica M9 lens codes
 # Inputs: 0) value
